# uw-iam-resttools

These are REST clients for IAM services at UW, including IRWS,
NWS (netid web service), GWS.

GWS v3 returns json payloads, which this client doesn't yet use. More
appropriate resources can be found at

* [GWS API definition](https://iam-tools.u.washington.edu/apis/gws/)
* [uw-restclients-gws package](https://pypi.org/project/UW-RestClients-GWS/)


